@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 # <examples/doc_model_loadmodelresult.py>
 import matplotlib.pyplot as plt
 import numpy as np
@@ -13,7 +11,7 @@ y = data[:, 1]
 result = load_modelresult('gauss_modelresult.sav')
 print(result.fit_report())
 
-plt.plot(x, y, 'bo')
-plt.plot(x, result.best_fit, 'r-')
+plt.plot(x, y, 'o')
+plt.plot(x, result.best_fit, '-')
 plt.show()
 # <end examples/doc_model_loadmodelresult.py>
