@@ -1,6 +1,5 @@
 """Implementation of the Model interface."""
 
-from collections import OrderedDict
 from copy import deepcopy
 from functools import wraps
 import inspect
@@ -8,16 +7,21 @@ import json
 import operator
 import warnings
 
+from asteval import valid_symbol_name
 import numpy as np
 from scipy.special import erf
 from scipy.stats import t
 
+import lmfit
+
 from . import Minimizer, Parameter, Parameters, lineshapes
 from .confidence import conf_interval
 from .jsonutils import HAS_DILL, decode4js, encode4js
 from .minimizer import MinimizerResult
 from .printfuncs import ci_report, fit_report, fitreport_html_table
 
+tiny = 1.e-15
+
 # Use pandas.isnull for aligning missing data if pandas is available.
 # otherwise use numpy.isnan
 try:
@@ -37,7 +41,7 @@ def _align(var, mask, data):
 
 
 try:
-    from matplotlib import pyplot as plt
+    import matplotlib  # noqa: F401
     _HAS_MATPLOTLIB = True
 except Exception:
     _HAS_MATPLOTLIB = False
@@ -70,7 +74,7 @@ def get_reducer(option):
 
     """
     if option not in ['real', 'imag', 'abs', 'angle']:
-        raise ValueError("Invalid option ('%s') for function 'propagate_err'." % option)
+        raise ValueError(f"Invalid option ('{option}') for function 'propagate_err'.")
 
     def reducer(array):
         """Convert a complex array to a real array.
@@ -134,15 +138,15 @@ def propagate_err(z, dz, option):
     so a value of `math:pi` is returned.
 
     In the case where ``option='abs'`` and ``numpy.abs(z) == 0`` for any
-    value of `z` the mangnitude uncertainty is approximated by
+    value of `z` the magnitude uncertainty is approximated by
     ``numpy.abs(dz)`` for that value.
 
     """
     if option not in ['real', 'imag', 'abs', 'angle']:
-        raise ValueError("Invalid option ('%s') for function 'propagate_err'." % option)
+        raise ValueError(f"Invalid option ('{option}') for function 'propagate_err'.")
 
-    if not z.shape == dz.shape:
-        raise ValueError("shape of z: %s != shape of dz: %s" % (z.shape, dz.shape))
+    if z.shape != dz.shape:
+        raise ValueError(f"shape of z: {z.shape} != shape of dz: {dz.shape}")
 
     # Check the main vector for complex. Do nothing if real.
     if any(np.iscomplex(z)):
@@ -262,7 +266,12 @@ class Model:
 
         """
         self.func = func
+        if not isinstance(prefix, str):
+            prefix = ''
+        if len(prefix) > 0 and not valid_symbol_name(prefix):
+            raise ValueError(f"'{prefix}' is not a valid Model prefix")
         self._prefix = prefix
+
         self._param_root_names = param_names  # will not include prefixes
         self.independent_vars = independent_vars
         self._func_allargs = []
@@ -270,8 +279,8 @@ class Model:
         self.nan_policy = nan_policy
 
         self.opts = kws
-        self.param_hints = OrderedDict()
         # the following has been changed from OrderedSet for the time being
+        self.param_hints = {}
         self._param_names = []
         self._parse_params()
         if self.independent_vars is None:
@@ -284,13 +293,13 @@ class Model:
         out = self._name
         opts = []
         if len(self._prefix) > 0:
-            opts.append("prefix='%s'" % (self._prefix))
+            opts.append(f"prefix='{self._prefix}'")
         if long:
             for k, v in self.opts.items():
-                opts.append("%s='%s'" % (k, v))
+                opts.append(f"{k}='{v}'")
         if len(opts) > 0:
-            out = "%s, %s" % (out, ', '.join(opts))
-        return "Model(%s)" % out
+            out = f"{out}, {', '.join(opts)}"
+        return f"Model({out})"
 
     def _get_state(self):
         """Save a Model for serialization.
@@ -449,7 +458,7 @@ class Model:
 
     def __repr__(self):
         """Return representation of Model."""
-        return "<lmfit.Model: %s>" % (self.name)
+        return f"<lmfit.Model: {self.name}>"
 
     def copy(self, **kwargs):
         """DOES NOT WORK."""
@@ -459,6 +468,8 @@ class Model:
         """Build parameters from function arguments."""
         if self.func is None:
             return
+        kw_args = {}
+        keywords_ = None
         # need to fetch the following from the function signature:
         #   pos_args: list of positional argument names
         #   kw_args: dict of keyword arguments with default values
@@ -466,15 +477,11 @@ class Model:
         # 1. limited support for asteval functions as the model functions:
         if hasattr(self.func, 'argnames') and hasattr(self.func, 'kwargs'):
             pos_args = self.func.argnames[:]
-            keywords_ = None
-            kw_args = {}
             for name, defval in self.func.kwargs:
                 kw_args[name] = defval
         # 2. modern, best-practice approach: use inspect.signature
         else:
             pos_args = []
-            kw_args = {}
-            keywords_ = None
             sig = inspect.signature(self.func)
             for fnam, fpar in sig.parameters.items():
                 if fpar.kind == fpar.VAR_KEYWORD:
@@ -485,7 +492,7 @@ class Model:
                     else:
                         kw_args[fnam] = fpar.default
                 elif fpar.kind == fpar.VAR_POSITIONAL:
-                    raise ValueError("varargs '*%s' is not supported" % fnam)
+                    raise ValueError(f"varargs '*{fnam}' is not supported")
         # inspection done
 
         self._func_haskeywords = keywords_ is not None
@@ -526,12 +533,9 @@ class Model:
                 new_opts[opt] = val
         self.opts = new_opts
 
-        names = []
         if self._prefix is None:
             self._prefix = ''
-        for pname in self._param_root_names:
-            names.append("%s%s" % (self._prefix, pname))
-
+        names = [f"{self._prefix}{pname}" for pname in self._param_root_names]
         # check variables names for validity
         # The implicit magic in fit() requires us to disallow some
         fname = self.func.__name__
@@ -589,7 +593,7 @@ class Model:
             name = name[npref:]
 
         if name not in self.param_hints:
-            self.param_hints[name] = OrderedDict()
+            self.param_hints[name] = {}
 
         for key, val in kwargs.items():
             if key in self._hint_names:
@@ -674,20 +678,20 @@ class Model:
                 par.value = kwargs[name]
             params.add(par)
             if verbose:
-                print(' - Adding parameter "%s"' % name)
+                print(f' - Adding parameter "{name}"')
 
         # next build parameters defined in param_hints
         # note that composites may define their own additional
         # convenience parameters here
         for basename, hint in self.param_hints.items():
-            name = "%s%s" % (self._prefix, basename)
+            name = f"{self._prefix}{basename}"
             if name in params:
                 par = params[name]
             else:
                 par = Parameter(name=name)
                 params.add(par)
                 if verbose:
-                    print(' - Adding parameter for hint "%s"' % name)
+                    print(f' - Adding parameter for hint "{name}"')
             par._delay_asteval = True
             for item in self._hint_names:
                 if item in hint:
@@ -702,7 +706,7 @@ class Model:
             p._delay_asteval = False
         return params
 
-    def guess(self, data, **kws):
+    def guess(self, data, x, **kws):
         """Guess starting values for the parameters of a Model.
 
         This is not implemented for all models, but is available for many
@@ -711,7 +715,9 @@ class Model:
         Parameters
         ----------
         data : array_like
-            Array of data to use to guess parameter values.
+            Array of data (i.e., y-values) to use to guess parameter values.
+        x : array_like
+            Array of values for the independent variable (i.e., x-values).
         **kws : optional
             Additional keyword arguments, passed to model function.
 
@@ -731,9 +737,12 @@ class Model:
         `self.make_params()`, update starting values and return a
         Parameters object.
 
+        .. versionchanged:: 1.0.3
+           Argument ``x`` is now explicitly required to estimate starting values.
+
         """
         cname = self.__class__.__name__
-        msg = 'guess() not implemented for %s' % cname
+        msg = f'guess() not implemented for {cname}'
         raise NotImplementedError(msg)
 
     def _residual(self, params, data, weights, **kwargs):
@@ -793,13 +802,24 @@ class Model:
             kwargs = {}
         out = {}
         out.update(self.opts)
+
+        # 1. fill in in all parameter values
         for name, par in params.items():
             if strip:
                 name = self._strip_prefix(name)
             if name in self._func_allargs or self._func_haskeywords:
                 out[name] = par.value
 
-        # kwargs handled slightly differently -- may set param value too!
+        # 2. for each function argument, use 'prefix+varname' in params,
+        # avoiding possible name collisions with unprefixed params
+        if len(self._prefix) > 0:
+            for fullname in self._param_names:
+                if fullname in params:
+                    name = self._strip_prefix(fullname)
+                    if name in self._func_allargs or self._func_haskeywords:
+                        out[name] = params[fullname].value
+
+        # 3. kwargs handled slightly differently -- may set param value too!
         for name, val in kwargs.items():
             if strip:
                 name = self._strip_prefix(name)
@@ -813,7 +833,7 @@ class Model:
         """Generate **all** function args for all functions."""
         args = {}
         for key, val in self.make_funcargs(params, kwargs).items():
-            args["%s%s" % (self._prefix, key)] = val
+            args[f"{self._prefix}{key}"] = val
         return args
 
     def eval(self, params=None, **kwargs):
@@ -828,7 +848,7 @@ class Model:
 
         Returns
         -------
-        numpy.ndarray
+        numpy.ndarray, float, int or complex
             Value of model given the parameters and other arguments.
 
         Notes
@@ -842,6 +862,11 @@ class Model:
         all the independent variables** will need to be passed in using
         keyword arguments.
 
+        3. The return type depends on the model function. For many of the
+        built-models it is a `numpy.ndarray`, with the exception of
+        `ConstantModel` and `ComplexConstantModel`, which return a `float`/`int`
+        or `complex` value.
+
         """
         return self.func(**self.make_funcargs(params, kwargs))
 
@@ -862,7 +887,7 @@ class Model:
 
         Returns
         -------
-        OrderedDict
+        dict
             Keys are prefixes for component model, values are value of
             each component.
 
@@ -884,8 +909,9 @@ class Model:
         params : Parameters, optional
             Parameters to use in fit (default is None).
         weights : array_like, optional
-            Weights to use for the calculation of the fit residual
-            (default is None). Must have the same size as `data`.
+            Weights to use for the calculation of the fit residual [i.e.,
+            `weights*(data-fit)`]. Default is None; must have the same size as
+            `data`.
         method : str, optional
             Name of fitting method to use (default is `'leastsq'`).
         iter_cb : callable, optional
@@ -965,34 +991,24 @@ class Model:
         # All remaining kwargs should correspond to independent variables.
         for name in kwargs:
             if name not in self.independent_vars:
-                warnings.warn("The keyword argument %s does not " % name +
+                warnings.warn(f"The keyword argument {name} does not " +
                               "match any arguments of the model function. " +
                               "It will be ignored.", UserWarning)
 
         # If any parameter is not initialized raise a more helpful error.
-        missing_param = any([p not in params.keys()
-                             for p in self.param_names])
-        blank_param = any([(p.value is None and p.expr is None)
-                           for p in params.values()])
+        missing_param = any(p not in params.keys() for p in self.param_names)
+        blank_param = any((p.value is None and p.expr is None)
+                          for p in params.values())
         if missing_param or blank_param:
             msg = ('Assign each parameter an initial value by passing '
                    'Parameters or keyword arguments to fit.\n')
             missing = [p for p in self.param_names if p not in params.keys()]
             blank = [name for name, p in params.items()
                      if p.value is None and p.expr is None]
-            msg += 'Missing parameters: %s\n' % str(missing)
-            msg += 'Non initialized parameters: %s' % str(blank)
+            msg += f'Missing parameters: {str(missing)}\n'
+            msg += f'Non initialized parameters: {str(blank)}'
             raise ValueError(msg)
 
-        # Do not alter anything that implements the array interface (np.array, pd.Series)
-        # but convert other iterables (e.g., Python lists) to NumPy arrays.
-        if not hasattr(data, '__array__'):
-            data = np.asfarray(data)
-        for var in self.independent_vars:
-            var_data = kwargs[var]
-            if isinstance(var_data, (list, tuple)):
-                kwargs[var] = np.asfarray(var_data)
-
         # Handle null/missing values.
         if nan_policy is not None:
             self.nan_policy = nan_policy
@@ -1007,12 +1023,27 @@ class Model:
 
         # If independent_vars and data are alignable (pandas), align them,
         # and apply the mask from above if there is one.
-
         for var in self.independent_vars:
             if not np.isscalar(kwargs[var]):
-                # print("Model fit align ind dep ", var, mask.sum())
                 kwargs[var] = _align(kwargs[var], mask, data)
 
+        # Make sure `dtype` for data is always `float64` or `complex128`
+        if np.isrealobj(data):
+            data = np.asfarray(data)
+        elif np.iscomplexobj(data):
+            data = np.asarray(data, dtype='complex128')
+
+        # Coerce `dtype` for independent variable(s) to `float64` or
+        # `complex128` when the variable has one of the following types: list,
+        # tuple, numpy.ndarray, or pandas.Series
+        for var in self.independent_vars:
+            var_data = kwargs[var]
+            if isinstance(var_data, (list, tuple, np.ndarray, Series)):
+                if np.isrealobj(var_data):
+                    kwargs[var] = np.asfarray(var_data)
+                elif np.iscomplexobj(var_data):
+                    kwargs[var] = np.asarray(var_data, dtype='complex128')
+
         if fit_kws is None:
             fit_kws = {}
 
@@ -1052,10 +1083,6 @@ class CompositeModel(Model):
 
     """
 
-    _names_collide = ("\nTwo models have parameters named '{clash}'. "
-                      "Use distinct names.")
-    _bad_arg = "CompositeModel: argument {arg} is not a Model"
-    _bad_op = "CompositeModel: operator {op} is not callable"
     _known_ops = {operator.add: '+', operator.sub: '-',
                   operator.mul: '*', operator.truediv: '/'}
 
@@ -1075,15 +1102,15 @@ class CompositeModel(Model):
 
         Notes
         -----
-        The two models must use the same independent variable.
+        The two models can use different independent variables.
 
         """
         if not isinstance(left, Model):
-            raise ValueError(self._bad_arg.format(arg=left))
+            raise ValueError(f'CompositeModel: argument {left} is not a Model')
         if not isinstance(right, Model):
-            raise ValueError(self._bad_arg.format(arg=right))
+            raise ValueError(f'CompositeModel: argument {right} is not a Model')
         if not callable(op):
-            raise ValueError(self._bad_op.format(op=op))
+            raise ValueError(f'CompositeModel: operator {op} is not callable')
 
         self.left = left
         self.right = right
@@ -1093,12 +1120,15 @@ class CompositeModel(Model):
         if len(name_collisions) > 0:
             msg = ''
             for collision in name_collisions:
-                msg += self._names_collide.format(clash=collision)
+                msg += (f"\nTwo models have parameters named '{collision}'; "
+                        "use distinct names.")
             raise NameError(msg)
 
-        # we assume that all the sub-models have the same independent vars
+        # the unique ``independent_vars`` of the left and right model are
+        # combined to ``independent_vars`` of the ``CompositeModel``
         if 'independent_vars' not in kws:
-            kws['independent_vars'] = self.left.independent_vars
+            ivars = self.left.independent_vars + self.right.independent_vars
+            kws['independent_vars'] = list(np.unique(ivars))
         if 'nan_policy' not in kws:
             kws['nan_policy'] = self.left.nan_policy
 
@@ -1109,7 +1139,7 @@ class CompositeModel(Model):
         for side in (left, right):
             prefix = side.prefix
             for basename, hint in side.param_hints.items():
-                self.param_hints["%s%s" % (prefix, basename)] = hint
+                self.param_hints[f"{prefix}{basename}"] = hint
 
     def _parse_params(self):
         self._func_haskeywords = (self.left._func_haskeywords or
@@ -1122,9 +1152,9 @@ class CompositeModel(Model):
         self.opts.update(self.left.opts)
 
     def _reprstring(self, long=False):
-        return "(%s %s %s)" % (self.left._reprstring(long=long),
-                               self._known_ops.get(self.op, self.op),
-                               self.right._reprstring(long=long))
+        return (f"({self.left._reprstring(long=long)} "
+                f"{self._known_ops.get(self.op, self.op)} "
+                f"{self.right._reprstring(long=long)})")
 
     def eval(self, params=None, **kwargs):
         """Evaluate model function for composite model."""
@@ -1132,8 +1162,8 @@ class CompositeModel(Model):
                        self.right.eval(params=params, **kwargs))
 
     def eval_components(self, **kwargs):
-        """Return OrderedDict of name, results for each component."""
-        out = OrderedDict(self.left.eval_components(**kwargs))
+        """Return dictionary of name, results for each component."""
+        out = dict(self.left.eval_components(**kwargs))
         out.update(self.right.eval_components(**kwargs))
         return out
 
@@ -1387,6 +1417,11 @@ class ModelResult(Minimizer):
                 except AttributeError:
                     pass
 
+        if self.data is not None and len(self.data) > 1:
+            sstot = ((self.data - self.data.mean())**2).sum()
+            if isinstance(self.residual, np.ndarray) and len(self.residual) > 1:
+                self.rsquared = 1.0 - (self.residual**2).sum()/max(tiny, sstot)
+
         self.init_values = self.model._make_all_args(self.init_params)
         self.best_values = self.model._make_all_args(_ret.params)
         self.best_fit = self.model.eval(params=_ret.params, **self.userkws)
@@ -1403,8 +1438,8 @@ class ModelResult(Minimizer):
 
         Returns
         -------
-        numpy.ndarray
-            Array for evaluated model.
+        numpy.ndarray, float, int, or complex
+            Array or value for the evaluated model.
 
         """
         userkws = self.userkws.copy()
@@ -1425,7 +1460,7 @@ class ModelResult(Minimizer):
 
         Returns
         -------
-        OrderedDict
+        dict
             Keys are prefixes of component models, and values are the
             estimated model value for each component of the model.
 
@@ -1468,6 +1503,10 @@ class ModelResult(Minimizer):
            < 1, it is interpreted as the probability itself. That is,
            ``sigma=1`` and ``sigma=0.6827`` will give the same results,
            within precision errors.
+        3. Also sets attributes of `dely` for the uncertainty of the model
+           (which will be the same as the array returned by this method) and
+           `dely_comps`, a dictionary of `dely` for each component.
+
 
         Examples
         --------
@@ -1489,10 +1528,16 @@ class ModelResult(Minimizer):
         # ensure fjac and df2 are correct size if independent var updated by kwargs
         ndata = self.model.eval(params, **userkws).size
         covar = self.covar
-        fjac = np.zeros((nvarys, ndata))
-        df2 = np.zeros(ndata)
-        if any([p.stderr is None for p in params.values()]):
-            return df2
+        if any(p.stderr is None for p in params.values()):
+            return np.zeros(ndata)
+
+        fjac = {'0': np.zeros((nvarys, ndata))}  # '0' signify 'Full', an invalid prefix
+        df2 = {'0': np.zeros(ndata)}
+
+        for comp in self.components:
+            label = comp.prefix if len(comp.prefix) > 1 else comp._name
+            fjac[label] = np.zeros((nvarys, ndata))
+            df2[label] = np.zeros(ndata)
 
         # find derivative by hand!
         pars = params.copy()
@@ -1500,25 +1545,35 @@ class ModelResult(Minimizer):
             pname = self.var_names[i]
             val0 = pars[pname].value
             dval = pars[pname].stderr/3.0
-
             pars[pname].value = val0 + dval
-            res1 = self.model.eval(pars, **userkws)
+            res1 = {'0': self.model.eval(pars, **userkws)}
+            res1.update(self.model.eval_components(params=pars, **userkws))
 
             pars[pname].value = val0 - dval
-            res2 = self.model.eval(pars, **userkws)
+            res2 = {'0': self.model.eval(pars, **userkws)}
+            res2.update(self.model.eval_components(params=pars, **userkws))
 
             pars[pname].value = val0
-            fjac[i] = (res1 - res2) / (2*dval)
+            for key in fjac:
+                fjac[key][i] = (res1[key] - res2[key]) / (2*dval)
 
         for i in range(nvarys):
             for j in range(nvarys):
-                df2 += fjac[i]*fjac[j]*covar[i, j]
+                for key in fjac:
+                    df2[key] += fjac[key][i] * fjac[key][j] * covar[i, j]
 
         if sigma < 1.0:
             prob = sigma
         else:
             prob = erf(sigma/np.sqrt(2))
-        return np.sqrt(df2) * t.ppf((prob+1)/2.0, self.ndata-nvarys)
+
+        scale = t.ppf((prob+1)/2.0, self.ndata-nvarys)
+        self.dely = scale * np.sqrt(df2.pop('0'))
+
+        self.dely_comps = {}
+        for key in df2:
+            self.dely_comps[key] = scale * np.sqrt(df2[key])
+        return self.dely
 
     def conf_interval(self, **kwargs):
         """Calculate the confidence intervals for the variable parameters.
@@ -1530,8 +1585,7 @@ class ModelResult(Minimizer):
         recalculating them.
 
         """
-        if self.ci_out is None:
-            self.ci_out = conf_interval(self, self, **kwargs)
+        self.ci_out = conf_interval(self, self, **kwargs)
         return self.ci_out
 
     def ci_report(self, with_offset=True, ndigits=5, **kwargs):
@@ -1590,14 +1644,14 @@ class ModelResult(Minimizer):
                             show_correl=show_correl,
                             min_correl=min_correl, sort_pars=sort_pars)
         modname = self.model._reprstring(long=True)
-        return '[[Model]]\n    %s\n%s' % (modname, report)
+        return f'[[Model]]\n    {modname}\n{report}'
 
     def _repr_html_(self, show_correl=True, min_correl=0.1):
         """Return a HTML representation of parameters data."""
         report = fitreport_html_table(self, show_correl=show_correl,
                                       min_correl=min_correl)
         modname = self.model._reprstring(long=True)
-        return "<h2> Model</h2> %s %s" % (modname, report)
+        return f"<h2> Model</h2> {modname} {report}"
 
     def dumps(self, **kws):
         """Represent ModelResult as a JSON string.
@@ -1625,12 +1679,13 @@ class ModelResult(Minimizer):
                                  for key in pasteval.user_defined_symbols()}
 
         for attr in ('aborted', 'aic', 'best_values', 'bic', 'chisqr',
-                     'ci_out', 'col_deriv', 'covar', 'errorbars',
-                     'flatchain', 'ier', 'init_values', 'lmdif_message',
-                     'message', 'method', 'nan_policy', 'ndata', 'nfev',
-                     'nfree', 'nvarys', 'redchi', 'scale_covar', 'calc_covar',
-                     'success', 'userargs', 'userkws', 'values', 'var_names',
-                     'weights', 'user_options'):
+                     'ci_out', 'col_deriv', 'covar', 'errorbars', 'flatchain',
+                     'ier', 'init_values', 'lmdif_message', 'message',
+                     'method', 'nan_policy', 'ndata', 'nfev', 'nfree',
+                     'nvarys', 'redchi', 'rsquared', 'scale_covar',
+                     'calc_covar', 'success', 'userargs', 'userkws', 'values',
+                     'var_names', 'weights', 'user_options'):
+
             try:
                 val = getattr(self, attr)
             except AttributeError:
@@ -1723,7 +1778,7 @@ class ModelResult(Minimizer):
                      'errorbars', 'fjac', 'flatchain', 'ier', 'init_fit',
                      'init_values', 'kws', 'lmdif_message', 'message',
                      'method', 'nan_policy', 'ndata', 'nfev', 'nfree',
-                     'nvarys', 'redchi', 'residual', 'scale_covar',
+                     'nvarys', 'redchi', 'residual', 'rsquared', 'scale_covar',
                      'calc_covar', 'success', 'userargs', 'userkws',
                      'var_names', 'weights', 'user_options'):
             setattr(self, attr, decode4js(modres.get(attr, None)))
@@ -1772,7 +1827,7 @@ class ModelResult(Minimizer):
     def plot_fit(self, ax=None, datafmt='o', fitfmt='-', initfmt='--',
                  xlabel=None, ylabel=None, yerr=None, numpoints=None,
                  data_kws=None, fit_kws=None, init_kws=None, ax_kws=None,
-                 show_init=False, parse_complex='abs'):
+                 show_init=False, parse_complex='abs', title=None):
         """Plot the fit results using matplotlib, if available.
 
         The plot will include the data points, the initial fit curve
@@ -1817,6 +1872,8 @@ class ModelResult(Minimizer):
             How to reduce complex data for plotting. Options are one of:
             `'abs'` (default), `'real'`, `'imag'`, or `'angle'`, which
             correspond to the NumPy functions with the same name.
+        title : str, optional
+            Matplotlib format string for figure title.
 
         Returns
         -------
@@ -1864,7 +1921,7 @@ class ModelResult(Minimizer):
             return False
 
         if not isinstance(ax, plt.Axes):
-            ax = plt.gca(**ax_kws)
+            ax = plt.axes(**ax_kws)
 
         x_array = self.userkws[independent_var]
 
@@ -1875,11 +1932,15 @@ class ModelResult(Minimizer):
             x_array_dense = x_array
 
         if show_init:
+            y_eval_init = self.model.eval(self.init_params,
+                                          **{independent_var: x_array_dense})
+            if isinstance(self.model, (lmfit.models.ConstantModel,
+                                       lmfit.models.ComplexConstantModel)):
+                y_eval_init *= np.ones(x_array_dense.size)
+
             ax.plot(
-                x_array_dense,
-                reduce_complex(self.model.eval(
-                    self.init_params, **{independent_var: x_array_dense})),
-                initfmt, label='init', **init_kws)
+                x_array_dense, reduce_complex(y_eval_init), initfmt,
+                label='initial fit', **init_kws)
 
         if yerr is None and self.weights is not None:
             yerr = 1.0/self.weights
@@ -1892,13 +1953,18 @@ class ModelResult(Minimizer):
             ax.plot(x_array, reduce_complex(self.data),
                     datafmt, label='data', **data_kws)
 
-        ax.plot(
-            x_array_dense,
-            reduce_complex(self.model.eval(self.params,
-                                           **{independent_var: x_array_dense})),
-            fitfmt, label='best-fit', **fit_kws)
+        y_eval = self.model.eval(self.params, **{independent_var: x_array_dense})
+        if isinstance(self.model, (lmfit.models.ConstantModel,
+                                   lmfit.models.ComplexConstantModel)):
+            y_eval *= np.ones(x_array_dense.size)
 
-        ax.set_title(self.model.name)
+        ax.plot(x_array_dense, reduce_complex(y_eval), fitfmt, label='best fit',
+                **fit_kws)
+
+        if title:
+            ax.set_title(title)
+        elif ax.get_title() == '':
+            ax.set_title(self.model.name)
         if xlabel is None:
             ax.set_xlabel(independent_var)
         else:
@@ -1907,12 +1973,13 @@ class ModelResult(Minimizer):
             ax.set_ylabel('y')
         else:
             ax.set_ylabel(ylabel)
-        ax.legend(loc='best')
+        ax.legend()
         return ax
 
     @_ensureMatplotlib
     def plot_residuals(self, ax=None, datafmt='o', yerr=None, data_kws=None,
-                       fit_kws=None, ax_kws=None, parse_complex='abs'):
+                       fit_kws=None, ax_kws=None, parse_complex='abs',
+                       title=None):
         """Plot the fit residuals using matplotlib, if available.
 
         If `yerr` is supplied or if the model included weights, errorbars
@@ -1937,6 +2004,8 @@ class ModelResult(Minimizer):
             How to reduce complex data for plotting. Options are one of:
             `'abs'` (default), `'real'`, `'imag'`, or `'angle'`, which
             correspond to the NumPy functions with the same name.
+        title : str, optional
+            Matplotlib format string for figure title.
 
         Returns
         -------
@@ -1982,32 +2051,40 @@ class ModelResult(Minimizer):
             return False
 
         if not isinstance(ax, plt.Axes):
-            ax = plt.gca(**ax_kws)
+            ax = plt.axes(**ax_kws)
 
         x_array = self.userkws[independent_var]
 
-        ax.axhline(0, **fit_kws)
+        ax.axhline(0, **fit_kws, color='k')
+
+        y_eval = self.model.eval(self.params, **{independent_var: x_array})
+        if isinstance(self.model, (lmfit.models.ConstantModel,
+                                   lmfit.models.ComplexConstantModel)):
+            y_eval *= np.ones(x_array.size)
 
         if yerr is None and self.weights is not None:
             yerr = 1.0/self.weights
-        if yerr is not None:
-            ax.errorbar(x_array, reduce_complex(self.eval()) - reduce_complex(self.data),
-                        yerr=propagate_err(self.data, yerr, parse_complex),
-                        fmt=datafmt, label='residuals', **data_kws)
-        else:
-            ax.plot(x_array, reduce_complex(self.eval()) - reduce_complex(self.data), datafmt,
-                    label='residuals', **data_kws)
 
-        ax.set_title(self.model.name)
+        residuals = reduce_complex(self.eval()) - reduce_complex(self.data)
+        if yerr is not None:
+            ax.errorbar(x_array, residuals,
+                        yerr=propagate_err(self.data, yerr, parse_complex),
+                        fmt=datafmt, **data_kws)
+        else:
+            ax.plot(x_array, residuals, datafmt, **data_kws)
+
+        if title:
+            ax.set_title(title)
+        elif ax.get_title() == '':
+            ax.set_title(self.model.name)
         ax.set_ylabel('residuals')
-        ax.legend(loc='best')
         return ax
 
     @_ensureMatplotlib
     def plot(self, datafmt='o', fitfmt='-', initfmt='--', xlabel=None,
              ylabel=None, yerr=None, numpoints=None, fig=None, data_kws=None,
              fit_kws=None, init_kws=None, ax_res_kws=None, ax_fit_kws=None,
-             fig_kws=None, show_init=False, parse_complex='abs'):
+             fig_kws=None, show_init=False, parse_complex='abs', title=None):
         """Plot the fit results and residuals using matplotlib.
 
         The method will produce a matplotlib figure (if package available)
@@ -2057,11 +2134,12 @@ class ModelResult(Minimizer):
             How to reduce complex data for plotting. Options are one of:
             `'abs'` (default), `'real'`, `'imag'`, or `'angle'`, which
             correspond to the NumPy functions with the same name.
+        title : str, optional
+            Matplotlib format string for figure title.
 
         Returns
         -------
-        tuple
-            A tuple with matplotlib's Figure and GridSpec objects.
+        matplotlib.figure.Figure
 
         See Also
         --------
@@ -2085,6 +2163,7 @@ class ModelResult(Minimizer):
         called, otherwise `fig_kws` is ignored.
 
         """
+        from matplotlib import pyplot as plt
         if data_kws is None:
             data_kws = {}
         if fit_kws is None:
@@ -2118,10 +2197,12 @@ class ModelResult(Minimizer):
                       initfmt=initfmt, xlabel=xlabel, ylabel=ylabel,
                       numpoints=numpoints, data_kws=data_kws,
                       fit_kws=fit_kws, init_kws=init_kws, ax_kws=ax_fit_kws,
-                      show_init=show_init, parse_complex=parse_complex)
+                      show_init=show_init, parse_complex=parse_complex,
+                      title=title)
         self.plot_residuals(ax=ax_res, datafmt=datafmt, yerr=yerr,
                             data_kws=data_kws, fit_kws=fit_kws,
-                            ax_kws=ax_res_kws, parse_complex=parse_complex)
+                            ax_kws=ax_res_kws, parse_complex=parse_complex,
+                            title=title)
         plt.setp(ax_res.get_xticklabels(), visible=False)
         ax_fit.set_title('')
-        return fig, gs
+        return fig
