@@ -1,9 +1,7 @@
 """Parameter class."""
 
-from collections import OrderedDict
 from copy import deepcopy
 import json
-import warnings
 
 from asteval import Interpreter, get_ast_names, valid_symbol_name
 from numpy import arcsin, array, cos, inf, isclose, sin, sqrt
@@ -13,7 +11,7 @@ from .jsonutils import decode4js, encode4js
 from .lineshapes import tiny
 from .printfuncs import params_html_table
 
-SCIPY_FUNCTIONS = {'gamfcn': scipy.special.gamma}
+SCIPY_FUNCTIONS = {'gamfcn': scipy.special.gamma, 'loggammafcn': scipy.special.loggamma, 'betalnfnc': scipy.special.betaln}
 for fnc_name in ('erf', 'erfc', 'wofz'):
     SCIPY_FUNCTIONS[fnc_name] = getattr(scipy.special, fnc_name)
 
@@ -24,8 +22,8 @@ def check_ast_errors(expr_eval):
         expr_eval.raise_exception(None)
 
 
-class Parameters(OrderedDict):
-    """An ordered dictionary of Parameter objects.
+class Parameters(dict):
+    """A dictionary of Parameter objects.
 
     It should contain all Parameter objects that are required to specify
     a fit model. All minimization and Model fitting routines in lmfit will
@@ -46,14 +44,10 @@ class Parameters(OrderedDict):
 
     """
 
-    def __init__(self, asteval=None, usersyms=None):
+    def __init__(self, usersyms=None):
         """
         Arguments
         ---------
-        asteval : :class:`asteval.Interpreter`, optional
-            Instance of the `asteval.Interpreter` to use for constraint
-            expressions. If None (default), a new interpreter will be
-            created. **Warning: deprecated**, use `usersyms` if possible!
         usersyms : dict, optional
             Dictionary of symbols to add to the
             :class:`asteval.Interpreter` (default is None).
@@ -61,15 +55,7 @@ class Parameters(OrderedDict):
         """
         super().__init__(self)
 
-        self._asteval = asteval
-        if asteval is None:
-            self._asteval = Interpreter()
-        else:
-            msg = ("The use of the 'asteval' argument for the Parameters class"
-                   " was deprecated in lmfit v0.9.12 and will be removed in a "
-                   "later release. Please use the 'usersyms' argument instead!")
-            warnings.warn(FutureWarning(msg))
-            self._asteval = asteval
+        self._asteval = Interpreter()
 
         _syms = {}
         _syms.update(SCIPY_FUNCTIONS)
@@ -85,7 +71,7 @@ class Parameters(OrderedDict):
     def update(self, other):
         """Update values and symbols with another Parameters object."""
         if not isinstance(other, Parameters):
-            raise ValueError("'%s' is not a Parameters object" % other)
+            raise ValueError(f"'{other}' is not a Parameters object")
         self.add_many(*other.values())
         for sym in other._asteval.user_defined_symbols():
             self._asteval.symtable[sym] = other._asteval.symtable[sym]
@@ -102,7 +88,7 @@ class Parameters(OrderedDict):
         all individual Parameter objects are copied.
 
         """
-        _pars = Parameters(asteval=None)
+        _pars = self.__class__()
 
         # find the symbols that were added by users, not during construction
         unique_symbols = {key: self._asteval.symtable[key]
@@ -132,12 +118,11 @@ class Parameters(OrderedDict):
 
     def __setitem__(self, key, par):
         """Set items of Parameters object."""
-        if key not in self:
-            if not valid_symbol_name(key):
-                raise KeyError("'%s' is not a valid Parameters name" % key)
+        if key not in self and not valid_symbol_name(key):
+            raise KeyError(f"'{key}' is not a valid Parameters name")
         if par is not None and not isinstance(par, Parameter):
-            raise ValueError("'%s' is not a Parameter" % par)
-        OrderedDict.__setitem__(self, key, par)
+            raise ValueError(f"'{par}' is not a Parameter")
+        dict.__setitem__(self, key, par)
         par.name = key
         par._expr_eval = self._asteval
         self._asteval.symtable[key] = par.value
@@ -145,7 +130,7 @@ class Parameters(OrderedDict):
     def __add__(self, other):
         """Add Parameters objects."""
         if not isinstance(other, Parameters):
-            raise ValueError("'%s' is not a Parameters object" % other)
+            raise ValueError(f"'{other}' is not a Parameters object")
         out = deepcopy(self)
         out.add_many(*other.values())
         for sym in other._asteval.user_defined_symbols():
@@ -203,6 +188,12 @@ class Parameters(OrderedDict):
         # then add all the parameters
         self.add_many(*state['params'])
 
+    def __repr__(self):
+        """__repr__ from OrderedDict."""
+        if not self:
+            return f'{self.__class__.__name__}()'
+        return f'{self.__class__.__name__}({list(self.items())!r})'
+
     def eval(self, expr):
         """Evaluate a statement using the `asteval` Interpreter.
 
@@ -266,10 +257,10 @@ class Parameters(OrderedDict):
 
         """
         if oneline:
-            return super().__repr__()
+            return self.__repr__()
         s = "Parameters({\n"
         for key in self.keys():
-            s += "    '%s': %s, \n" % (key, self[key])
+            s += f"    '{key}': {self[key]}, \n"
         s += "    })\n"
         return s
 
@@ -310,7 +301,7 @@ class Parameters(OrderedDict):
         otherstyles = dict(name='{name:<{name_len}} ', stderr='{stderr!s:>{n}}',
                            vary='{vary!s:>{n}}', expr='{expr!s:>{n}}',
                            brute_step='{brute_step!s:>{n}}')
-        line = ' '.join([otherstyles.get(k, numstyle % k) for k in allcols])
+        line = ' '.join(otherstyles.get(k, numstyle % k) for k in allcols)
         for name, values in sorted(self.items()):
             pvalues = {k: getattr(values, k) for k in columns}
             pvalues['name'] = name
@@ -334,9 +325,11 @@ class Parameters(OrderedDict):
 
         Parameters
         ----------
-        name : str
-            Name of parameter. Must match ``[a-z_][a-z0-9_]*`` and cannot
-            be a Python reserved word.
+        name : str or Parameter
+            If ``name`` refers to a Parameter object it will be added directly
+            to the Parameters instance, otherwise a new Parameter object with name
+            ``string`` is created before adding it. In both cases, ``name`` must
+            match ``[a-z_][a-z0-9_]*`` and cannot be a Python reserved word.
         value : float, optional
             Numerical Parameter value, typically the *initial value*.
         vary : bool, optional
@@ -415,12 +408,12 @@ class Parameters(OrderedDict):
 
         Returns
         -------
-        OrderedDict
-            An ordered dictionary of :attr:`name`::attr:`value` pairs for
-            each Parameter.
+        dict
+            A dictionary of :attr:`name`::attr:`value` pairs for each
+            Parameter.
 
         """
-        return OrderedDict((p.name, p.value) for p in self.values())
+        return {p.name: p.value for p in self.values()}
 
     def dumps(self, **kws):
         """Represent Parameters as a JSON string.
@@ -695,7 +688,7 @@ class Parameter:
         if self.min > self.max:
             self.min, self.max = self.max, self.min
         if isclose(self.min, self.max, atol=1e-13, rtol=1e-13):
-            raise ValueError("Parameter '%s' has min == max" % self.name)
+            raise ValueError(f"Parameter '{self.name}' has min == max")
         if self._val > self.max:
             self._val = self.max
         if self._val < self.min:
@@ -717,24 +710,25 @@ class Parameter:
         self._expr_eval = None
         self._expr_deps = []
         self._delay_asteval = False
-        self.value = _value
+        self._val = _value
         self._init_bounds()
+        self.value = _value
 
     def __repr__(self):
         """Return printable representation of a Parameter object."""
         s = []
-        sval = "value=%s" % repr(self._getval())
+        sval = f"value={repr(self._getval())}"
         if not self.vary and self._expr is None:
             sval += " (fixed)"
         elif self.stderr is not None:
-            sval += " +/- %.3g" % self.stderr
+            sval += f" +/- {self.stderr:.3g}"
         s.append(sval)
-        s.append("bounds=[%s:%s]" % (repr(self.min), repr(self.max)))
+        s.append(f"bounds=[{repr(self.min)}:{repr(self.max)}]")
         if self._expr is not None:
-            s.append("expr='%s'" % self.expr)
+            s.append(f"expr='{self.expr}'")
         if self.brute_step is not None:
-            s.append("brute_step=%s" % (self.brute_step))
-        return "<Parameter '%s', %s>" % (self.name, ', '.join(s))
+            s.append(f"brute_step={self.brute_step}")
+        return f"<Parameter '{self.name}', {', '.join(s)}>"
 
     def setup_bounds(self):
         """Set up Minuit-style internal/external parameter transformation
@@ -810,10 +804,9 @@ class Parameter:
         if self._expr is not None:
             if self._expr_ast is None:
                 self.__set_expression(self._expr)
-            if self._expr_eval is not None:
-                if not self._delay_asteval:
-                    self.value = self._expr_eval(self._expr_ast)
-                    check_ast_errors(self._expr_eval)
+            if self._expr_eval is not None and not self._delay_asteval:
+                self.value = self._expr_eval(self._expr_ast)
+                check_ast_errors(self._expr_eval)
         return self._val
 
     @property
