@@ -2,7 +2,6 @@
 
 from math import log10
 import re
-import warnings
 
 import numpy as np
 
@@ -25,7 +24,7 @@ def getfloat_attr(obj, attr, length=11):
     if val is None:
         return 'unknown'
     if isinstance(val, int):
-        return '%d' % val
+        return f'{val}'
     if isinstance(val, float):
         return gformat(val, length=length).strip()
     return repr(val)
@@ -74,11 +73,7 @@ def gformat(val, length=11):
         prec += 4
         if expon > 0:
             prec -= expon
-    fmt = '{0: %i.%i%s}' % (length, prec, form)
-    return fmt.format(val)[:length]
-
-
-CORREL_HEAD = '[[Correlations]] (unreported correlations are < %.3f)'
+    return f'{val:{length}.{prec}{form}}'
 
 
 def fit_report(inpars, modelpars=None, show_correl=True, min_correl=0.1,
@@ -131,17 +126,19 @@ def fit_report(inpars, modelpars=None, show_correl=True, min_correl=0.1,
 
     buff = []
     add = buff.append
-    namelen = max([len(n) for n in parnames])
+    namelen = max(len(n) for n in parnames)
     if result is not None:
         add("[[Fit Statistics]]")
-        add("    # fitting method   = %s" % (result.method))
-        add("    # function evals   = %s" % getfloat_attr(result, 'nfev'))
-        add("    # data points      = %s" % getfloat_attr(result, 'ndata'))
-        add("    # variables        = %s" % getfloat_attr(result, 'nvarys'))
-        add("    chi-square         = %s" % getfloat_attr(result, 'chisqr'))
-        add("    reduced chi-square = %s" % getfloat_attr(result, 'redchi'))
-        add("    Akaike info crit   = %s" % getfloat_attr(result, 'aic'))
-        add("    Bayesian info crit = %s" % getfloat_attr(result, 'bic'))
+        add(f"    # fitting method   = {result.method}")
+        add(f"    # function evals   = {getfloat_attr(result, 'nfev')}")
+        add(f"    # data points      = {getfloat_attr(result, 'ndata')}")
+        add(f"    # variables        = {getfloat_attr(result, 'nvarys')}")
+        add(f"    chi-square         = {getfloat_attr(result, 'chisqr')}")
+        add(f"    reduced chi-square = {getfloat_attr(result, 'redchi')}")
+        add(f"    Akaike info crit   = {getfloat_attr(result, 'aic')}")
+        add(f"    Bayesian info crit = {getfloat_attr(result, 'bic')}")
+        if hasattr(result, 'rsquared'):
+            add(f"    R-squared          = {getfloat_attr(result, 'rsquared')}")
         if not result.errorbars:
             add("##  Warning: uncertainties could not be estimated:")
             if result.method in ('leastsq', 'least_squares') or HAS_NUMDIFFTOOLS:
@@ -151,9 +148,9 @@ def fit_report(inpars, modelpars=None, show_correl=True, min_correl=0.1,
                     par = params[name]
                     space = ' '*(namelen-len(name))
                     if par.init_value and np.allclose(par.value, par.init_value):
-                        add('    %s:%s  at initial value' % (name, space))
+                        add(f'    {name}:{space}  at initial value')
                     if (np.allclose(par.value, par.min) or np.allclose(par.value, par.max)):
-                        add('    %s:%s  at boundary' % (name, space))
+                        add(f'    {name}:{space}  at boundary')
             else:
                 add("    this fitting method does not natively calculate uncertainties")
                 add("    and numdifftools is not installed for lmfit to do this. Use")
@@ -164,12 +161,12 @@ def fit_report(inpars, modelpars=None, show_correl=True, min_correl=0.1,
     for name in parnames:
         par = params[name]
         space = ' '*(namelen-len(name))
-        nout = "%s:%s" % (name, space)
+        nout = f"{name}:{space}"
         inval = '(init = ?)'
         if par.init_value is not None:
-            inval = '(init = %.7g)' % par.init_value
+            inval = f'(init = {par.init_value:.7g})'
         if modelpars is not None and name in modelpars:
-            inval = '%s, model_value = %.7g' % (inval, modelpars[name].value)
+            inval = f'{inval}, model_value = {modelpars[name].value:.7g}'
         try:
             sval = gformat(par.value)
         except (TypeError, ValueError):
@@ -177,17 +174,17 @@ def fit_report(inpars, modelpars=None, show_correl=True, min_correl=0.1,
         if par.stderr is not None:
             serr = gformat(par.stderr)
             try:
-                spercent = '({:.2%})'.format(abs(par.stderr/par.value))
+                spercent = f'({abs(par.stderr/par.value):.2%})'
             except ZeroDivisionError:
                 spercent = ''
-            sval = '%s +/-%s %s' % (sval, serr, spercent)
+            sval = f'{sval} +/-{serr} {spercent}'
 
         if par.vary:
-            add("    %s %s %s" % (nout, sval, inval))
+            add(f"    {nout} {sval} {inval}")
         elif par.expr is not None:
-            add("    %s %s == '%s'" % (nout, sval, par.expr))
+            add(f"    {nout} {sval} == '{par.expr}'")
         else:
-            add("    %s % .7g (fixed)" % (nout, par.value))
+            add(f"    {nout} {par.value: .7g} (fixed)")
 
     if show_correl:
         correls = {}
@@ -199,16 +196,17 @@ def fit_report(inpars, modelpars=None, show_correl=True, min_correl=0.1,
                 for name2 in parnames[i+1:]:
                     if (name != name2 and name2 in par.correl and
                             abs(par.correl[name2]) > min_correl):
-                        correls["%s, %s" % (name, name2)] = par.correl[name2]
+                        correls[f"{name}, {name2}"] = par.correl[name2]
 
         sort_correl = sorted(correls.items(), key=lambda it: abs(it[1]))
         sort_correl.reverse()
         if len(sort_correl) > 0:
-            add(CORREL_HEAD % min_correl)
-            maxlen = max([len(k) for k in list(correls.keys())])
+            add('[[Correlations]] (unreported correlations are < '
+                f'{min_correl:.3f})')
+            maxlen = max(len(k) for k in list(correls.keys()))
         for name, val in sort_correl:
             lspace = max(0, maxlen - len(name))
-            add('    C(%s)%s = % .3f' % (name, (' '*30)[:lspace], val))
+            add(f"    C({name}){(' '*30)[:lspace]} = {val:.3f}")
     return '\n'.join(buff)
 
 
@@ -235,7 +233,7 @@ def fitreport_html_table(result, show_correl=True, min_correl=0.1):
     add = html.append
 
     def stat_row(label, val, val2=''):
-        add('<tr><td>%s</td><td>%s</td><td>%s</td></tr>' % (label, val, val2))
+        add(f'<tr><td>{label}</td><td>{val}</td><td>{val2}</td></tr>')
 
     add('<h2>Fit Statistics</h2>')
     add('<table>')
@@ -247,6 +245,8 @@ def fitreport_html_table(result, show_correl=True, min_correl=0.1):
     stat_row('reduced chi-square', gformat(result.redchi))
     stat_row('Akaike info crit.', gformat(result.aic))
     stat_row('Bayesian info crit.', gformat(result.bic))
+    if hasattr(result, 'rsquared'):
+        stat_row('R-squared', gformat(result.rsquared))
     add('</table>')
     add('<h2>Variables</h2>')
     add(params_html_table(result.params))
@@ -265,11 +265,11 @@ def fitreport_html_table(result, show_correl=True, min_correl=0.1):
         if len(correls) > 0:
             sort_correls = sorted(correls, key=lambda val: abs(val[2]))
             sort_correls.reverse()
-            extra = '(unreported correlations are < %.3f)' % (min_correl)
-            add('<h2>Correlations %s</h2>' % extra)
+            extra = f'(unreported correlations are < {min_correl:.3f})'
+            add(f'<h2>Correlations {extra}</h2>')
             add('<table>')
             for name1, name2, val in sort_correls:
-                stat_row(name1, name2, "%.4f" % val)
+                stat_row(name1, name2, f"{val:.4f}")
             add('</table>')
     return ''.join(html)
 
@@ -288,15 +288,15 @@ def params_html_table(params):
         Multi-line HTML code of fitting parameters.
 
     """
-    has_err = any([p.stderr is not None for p in params.values()])
-    has_expr = any([p.expr is not None for p in params.values()])
-    has_brute = any([p.brute_step is not None for p in params.values()])
+    has_err = any(p.stderr is not None for p in params.values())
+    has_expr = any(p.expr is not None for p in params.values())
+    has_brute = any(p.brute_step is not None for p in params.values())
 
     html = []
     add = html.append
 
     def cell(x, cat='td'):
-        return add('<%s> %s </%s>' % (cat, x, cat))
+        return add(f'<{cat}> {x} </{cat}>')
 
     add('<table><tr>')
     headers = ['name', 'value']
@@ -315,21 +315,21 @@ def params_html_table(params):
         rows = [par.name, gformat(par.value)]
         if has_err:
             serr = ''
+            spercent = ''
             if par.stderr is not None:
                 serr = gformat(par.stderr)
                 try:
-                    spercent = '({:.2%})'.format(abs(par.stderr/par.value))
+                    spercent = f'({abs(par.stderr/par.value):.2%})'
                 except ZeroDivisionError:
-                    spercent = ''
+                    pass
             rows.extend([serr, spercent])
         rows.extend((par.init_value, gformat(par.min),
-                     gformat(par.max), '%s' % par.vary))
+                     gformat(par.max), f'{par.vary}'))
         if has_expr:
             expr = ''
             if par.expr is not None:
                 expr = par.expr
             rows.append(expr)
-
         if has_brute:
             brute_step = 'None'
             if par.brute_step is not None:
@@ -344,14 +344,6 @@ def params_html_table(params):
     return ''.join(html)
 
 
-def report_errors(params, **kws):
-    """Print a report for fitted params: see error_report()."""
-    warnings.warn("The function 'report_errors' is deprecated as of lmfit "
-                  "0.9.14 and will be removed in the next release. Please "
-                  "use 'report_fit' instead.", FutureWarning)
-    print(fit_report(params, **kws))
-
-
 def report_fit(params, **kws):
     """Print a report of the fitting results."""
     print(fit_report(params, **kws))
@@ -377,7 +369,7 @@ def ci_report(ci, with_offset=True, ndigits=5):
         Text of formatted report on confidence intervals.
 
     """
-    maxlen = max([len(i) for i in ci])
+    maxlen = max(len(i) for i in ci)
     buff = []
     add = buff.append
 
@@ -385,7 +377,7 @@ def ci_report(ci, with_offset=True, ndigits=5):
         """Convert probabilities into header for CI report."""
         if abs(x[0]) < 1.e-2:
             return "_BEST_"
-        return "%.2f%%" % (x[0]*100)
+        return f"{x[0] * 100:.2f}%"
 
     title_shown = False
     fmt_best = fmt_diff = "{0:.%if}" % ndigits
@@ -396,7 +388,7 @@ def ci_report(ci, with_offset=True, ndigits=5):
             add("".join([''.rjust(maxlen+1)] + [i.rjust(ndigits+5)
                                                 for i in map(convp, row)]))
             title_shown = True
-        thisrow = [" %s:" % name.ljust(maxlen)]
+        thisrow = [f" {name.ljust(maxlen)}:"]
         offset = 0.0
         if with_offset:
             for cval, val in row:
