@@ -4,7 +4,6 @@
 from copy import copy, deepcopy
 import pickle
 
-import asteval
 import numpy as np
 from numpy.testing import assert_allclose
 import pytest
@@ -45,21 +44,9 @@ def test_check_ast_errors():
         pars.add('par1', expr='2.0*par2')
 
 
-def test_parameters_init_with_asteval():
-    """Test for initialization of the Parameters class with asteval."""
-    ast_int = asteval.Interpreter()
-
-    msg = ("The use of the 'asteval' argument for the Parameters class was "
-           "deprecated in lmfit v0.9.12 and will be removed in a later "
-           "release. Please use the 'usersyms' argument instead!")
-    with pytest.warns(FutureWarning, match=msg):
-        pars = lmfit.Parameters(asteval=ast_int)
-    assert pars._asteval == ast_int
-
-
 def test_parameters_init_with_usersyms():
     """Test for initialization of the Parameters class with usersyms."""
-    pars = lmfit.Parameters(asteval=None, usersyms={'test': np.sin})
+    pars = lmfit.Parameters(usersyms={'test': np.sin})
     assert 'test' in pars._asteval.symtable
 
 
@@ -111,6 +98,18 @@ def test_parameters_deepcopy(parameters):
                     deepcopy_pars._asteval.symtable[unique_symbol])
 
 
+def test_parameters_deepcopy_subclass():
+    """Test that a subclass of parameters is preserved when performing a deepcopy"""
+    class ParametersSubclass(lmfit.Parameters):
+        pass
+
+    parameters = ParametersSubclass()
+    assert isinstance(parameters, ParametersSubclass)
+
+    parameterscopy = deepcopy(parameters)
+    assert isinstance(parameterscopy, ParametersSubclass)
+
+
 def test_parameters_update(parameters):
     """Tests for updating a Parameters class."""
     pars, exp_attr_values_A, exp_attr_values_B = parameters
@@ -274,7 +273,7 @@ def test_pickle_parameters():
     # check that unpickling of Parameters is not affected by expr that
     # refer to Parameter that are added later on. In the following
     # example var_0.expr refers to var_1, which is a Parameter later
-    # on in the Parameters OrderedDict.
+    # on in the Parameters dictionary.
     p = lmfit.Parameters()
     p.add('var_0', value=1)
     p.add('var_1', value=2)
