@@ -4,10 +4,11 @@ import pytest
 
 import lmfit
 from lmfit import (Minimizer, Parameters, ci_report, conf_interval, fit_report,
-                   report_ci, report_errors, report_fit)
+                   report_ci, report_fit)
 from lmfit.lineshapes import gaussian
 from lmfit.models import GaussianModel
-from lmfit.printfuncs import alphanumeric_sort, getfloat_attr, gformat
+from lmfit.printfuncs import (alphanumeric_sort, fitreport_html_table,
+                              getfloat_attr, gformat)
 
 np.random.seed(0)
 
@@ -222,12 +223,6 @@ def test_report_fit(fitresult, capsys):
         assert header in captured.out
 
 
-def test_report_errors_deprecated(fitresult):
-    """Verify that a FutureWarning is shown when calling report_errors."""
-    with pytest.warns(FutureWarning):
-        report_errors(params=fitresult.params)
-
-
 def test_report_leastsq_no_errorbars(fitresult):
     """Verify correct message when uncertainties could not be estimated."""
     # general warning is shown
@@ -333,6 +328,25 @@ def test_report_zero_value_spercent(fitresult):
     assert '%' in html_params_split[indx+1]
 
 
+@pytest.mark.skipif(not lmfit.minimizer.HAS_EMCEE, reason="requires emcee v3")
+def test_spercent_html_table():
+    """Regression test for GitHub Issue #768."""
+    np.random.seed(2021)
+    x = np.random.uniform(size=100)
+    y = x + 0.1 * np.random.uniform(size=x.size)
+
+    def res(par, x, y):
+        return y - par['k'] * x + par['b']
+
+    params = lmfit.Parameters()
+    params.add('b', 0, vary=False)
+    params.add('k', 1)
+
+    fitter = lmfit.Minimizer(res, params, fcn_args=(x, y))
+    fit_res = fitter.minimize(method='emcee', steps=5)
+    fitreport_html_table(fit_res)
+
+
 def test_ci_report(confidence_interval):
     """Verify that the CI report is created when using ci_report."""
     report = ci_report(confidence_interval)
